===============================
Ambient Radio Weather Network
===============================

.. image:: https://img.shields.io/pypi/v/arwn.svg
        :target: https://pypi.python.org/pypi/arwn

.. image:: https://img.shields.io/travis/sdague/arwn.svg
        :target: https://travis-ci.org/sdague/arwn

..
   .. image:: https://readthedocs.org/projects/arwn/badge/?version=latest
           :target: https://readthedocs.org/projects/arwn/?badge=latest
           :alt: Documentation Status


Collect 433Mhz weather sensor data and publish to mqtt.

This software is designed to use an rfxcom usb receiver and relay the
data found on it over an mqtt bus so that it can be consumed by other
software, such as Home Assistant.

It also provides a mechanism for reporting the weather data to Weather
Underground.


* Free software: Apache license
..
   * Documentation: https://arwn.readthedocs.org.

TODO
----

* User documentation

Credits
---------

Sean Dague
